import request from '@/utils/request'
import { AxiosPromise } from 'axios'

// apiUrl 数据库管理
const api = {
	page: '/gen/database/page',
	create: '/gen/database/create',
	update: '/gen/database/update',
	delete: '/gen/database/delete',
	listSelectOptions: '/gen/database/list-select-options',
	get: '/gen/database/get'
}

/**
 * 数据库管理 - 分页列表
 */
function databasePageApi(data: any): AxiosPromise {
	return request({
		url: api.page,
		method: 'post',
		data
	})
}

/**
 * 数据库管理 - 创建或更新
 */
function databaseAddOrEditSaveApi(data: any): AxiosPromise {
	return request({
		url: data.id ? api.update : api.create,
		method: 'post',
		data
	})
}

/**
 * 数据库管理 - 删除
 */
function databaseDeleteApi(data: any): AxiosPromise {
	return request({
		url: api.delete,
		method: 'post',
		data
	})
}

/**
 * 数据库管理 - 下拉选项列表
 */
function databaseListSelectOptionsApi(): AxiosPromise {
	return request({
		url: api.listSelectOptions,
		method: 'get'
	})
}

/**
 * 数据库管理 - 查询 ID 信息
 */
function databaseGetApi(id: any): AxiosPromise {
	return request({
		url: `${api.get}?id=${id}`,
		method: 'get'
	})
}

export default {
	databasePageApi,
	databaseAddOrEditSaveApi,
	databaseDeleteApi,
	databaseListSelectOptionsApi,
	databaseGetApi
}